Permit.UndefinedActionError exception (permit v0.3.3)
View SourceRaised when a given action is not implemented in the actions module (implementing Permit.Actions).
Raised when a given action is not implemented in the actions module (implementing Permit.Actions).